pub struct Animatable<T: SpringScalar + 'static> { /* private fields */ }Expand description
Generic animatable value holder.
Implementations
Sourceimpl<T: SpringScalar + 'static> Animatable<T>
impl<T: SpringScalar + 'static> Animatable<T>
Sourcepub fn new(initial: T, runtime: RuntimeHandle) -> Self
pub fn new(initial: T, runtime: RuntimeHandle) -> Self
Create a new animatable with the given initial value.
Sourcepub fn animateTo(&mut self, target: T, animation: AnimationType)
pub fn animateTo(&mut self, target: T, animation: AnimationType)
Animate to the target value using the specified animation.
Sourcepub fn animation_type(&self) -> AnimationType
pub fn animation_type(&self) -> AnimationType
Return the animation spec currently driving this animatable.